-- Filename:     tb_pres_beep.vhd
-- Filetype:     VHDL Testbench code
-- Date:         14 july 2014
-- Update:       -
-- Description:  VHDL Testbench for pres_beep.vhd
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.0
-- Copyright:    (c)2014, De Haagse Hogeschool

-- This VHDL code houses the VHDL Testbench for simulating
-- the prescaler/beeper code.
--
-- Note: simulation takes a long time due to the Altera PLL
--       VITAL library.

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

-- Empty testbench entity
entity tb_pres_beep is
end entity tb_pres_beep;

-- The architecture...
architecture sim of tb_pres_beep is
component pres_beep is
		port (clk_50MHz : in std_logic;
		      areset    : in std_logic;
				beep      : in std_logic;
				clk_32768 : out std_logic;
				locked    : out std_logic;
				piezo     : out std_logic
			  );
end component pres_beep;
signal clk_50MHz : std_logic;
signal areset    : std_logic;
signal beep      : std_logic;
signal clk_32768 : std_logic;
signal locked    : std_logic;
signal piezo     : std_logic;

-- 50 MHz clock oscillator
constant Tperiod : time := 20 ns;
begin

    -- Map the prescaler/beeper
    dut: pres_beep
    port map (clk_50MHz => clk_50MHz, areset => areset, beep => beep,
	           clk_32768 => clk_32768, locked => locked, piezo => piezo);

    -- Generate 50 MHz clock...  
    clockgen: process is
	 begin
        clk_50MHz <= '0';
		  wait for Tperiod/2;
        clk_50MHz <= '1';
		  wait for Tperiod/2;
	 end process;

    -- Reset the lot, then sit and wait...	 
    datagen: process is
	 begin
        areset <= '1';
        beep <= '0';
		  wait until clk_50MHz = '1';
		  wait until clk_50MHz = '1';
        areset <= '0';
        beep <= '1';
		  wait;
    end process;

end architecture sim;
